# melpoi
[![PyPI Latest Release](https://img.shields.io/pypi/v/melpoi.svg)](https://pypi.org/project/melpoi/)
[![release](https://github.com/la0bing/melpoi/actions/workflows/release.yml/badge.svg?branch=master)](https://github.com/la0bing/melpoi/actions/workflows/release.yml)

melpoi is a python library to mainly to speed up data discovery, data analyzing, etc.

# Get Started
```
pip install melpoi
```

# Categories
- [SQL](https://github.com/la0bing/melpoi/tree/master/melpoi/sql)


# Categories working in progerss
- Dataset auto analyzer
- AutoML
